@@ -46,12 +46,16 @@ simple_reporter_ui <- function(id) {
 #' @param reporter [`Reporter`] instance.
 #' @param card_fun `function` which returns a [`ReportCard`] instance,
 #' the function has a `card` argument and an optional `comment` argument.
+#' @param global_knitr `list` a global `knitr` parameters for customizing the rendering process.
 #' @inheritParams reporter_download_inputs
+#' @details `r global_knitr_details()`
+#'
 #' @return `shiny::moduleServer`
 #' @export
 simple_reporter_srv <- function(id,
                                 reporter,
                                 card_fun,
+                                global_knitr = getOption("teal.reporter.global_knitr"),
                                 rmd_output = c(
                                   "html" = "html_document", "pdf" = "pdf_document",
                                   "powerpoint" = "powerpoint_presentation", "word" = "word_document"
@@ -68,6 +72,7 @@ simple_reporter_srv <- function(id,
       download_report_button_srv(
         "download_button_simple",
         reporter = reporter,
+        global_knitr = global_knitr,
         rmd_output = rmd_output,
         rmd_yaml_args = rmd_yaml_args
       )
