@@ -6,7 +6,8 @@ TableBlock <- R6::R6Class( # nolint: object_name_linter.
   public = list(
     #' @description Returns a new `TableBlock` object
     #'
-    #' @param table (`data.frame`, `rtables`, `TableTree`, `ElementaryTable`) a table assigned to this `TableBlock`
+    #' @param table (`data.frame`, `rtables`, `TableTree`, `ElementaryTable`, `listing_df`) a table assigned to
+    #'   this `TableBlock`
     #'
     #' @return a `TableBlock` object
     initialize = function(table) {
@@ -19,11 +20,18 @@ TableBlock <- R6::R6Class( # nolint: object_name_linter.
     #'
     #' @details throws if argument is not a table-like object.
     #'
-    #' @param content (`data.frame`, `rtables`, `TableTree`, `ElementaryTable`) a table assigned to this `TableBlock`
+    #' @param content (`data.frame`, `rtables`, `TableTree`, `ElementaryTable`, `listing_df`) a table assigned to
+    #'   this `TableBlock`
     #'
     #' @return invisibly self
+    #' @examples
+    #' TableBlock <- getFromNamespace("TableBlock", "teal.reporter")
+    #' block <- TableBlock$new()
+    #' block$set_content(iris)
+    #'
     set_content = function(content) {
       checkmate::assert_multi_class(content, private$supported_tables)
+      content <- to_flextable(content)
       path <- tempfile(fileext = ".rds")
       saveRDS(content, file = path)
       super$set_content(path)
@@ -31,7 +39,7 @@ TableBlock <- R6::R6Class( # nolint: object_name_linter.
     }
   ),
   private = list(
-    supported_tables = c("data.frame", "rtables", "TableTree", "ElementaryTable")
+    supported_tables = c("data.frame", "rtables", "TableTree", "ElementaryTable", "listing_df")
   ),
   lock_objects = TRUE,
   lock_class = TRUE
