@@ -1,15 +1,10 @@
 #' Reporting tools for `shiny` modules.
 #'
-#' @description
 #' A collection of tools for creating, previewing and modifying reports from `shiny` modules.
 #'
-#' @docType package
 #' @keywords internal
-#' @name teal.reporter
-NULL
+"_PACKAGE"
 
-#' To avoid R CMD check warnings.
-#' @noRd
 #' @importFrom checkmate assert_string
 #' @importFrom grid grid.newpage
 #' @importFrom lifecycle badge
